@@ -3,7 +3,7 @@
 package App::WHMCSUtils;
 
 our $DATE = '2018-01-25'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -308,7 +308,7 @@ then defers the revenue to separate months for items that should be deferred,
 and finally sums the amounts to calculate total monthly deferred revenues.
 
 This utility can also be instructed (via setting the `full` option to true) to
-output the full report (each items with their categorizations and deferred
+output the full CSV report (each items with their categorizations and deferred
 revenues).
 
 Recognizes English and Indonesian description text.
@@ -323,6 +323,30 @@ Categorization heuristics:
 
 Extra rules (applied first) can be specified via the `extra_rules` option.
 
+To use this utility, install the Perl CPAN distribution <pm:App::WHMCSUtils>.
+Then, create a configuration file `~/whmcs-calc-deferred-revenue.conf`
+containing something like:
+
+    db_name=YOURDBNAME
+    db_host=YOURDBHOST
+    db_user=YOURDBUSER
+    db_pass=YOURDBPASS
+
+`db_host` defaults to `localhost`. `db_user` and `db_pass` can be omitted if you
+have `/etc/my.cnf` or `~/.my.cnf`. This utility can search for username/password
+from those files.
+
+You can also add other configuration like `extra_rules`, e.g.:
+
+    extra_rules=[{"type": "^$", "description": "^(?^i)sewa\\b.*ruang", "category": "rent"}]
+
+You can then run the utility for the desired, e.g.:
+
+    % whmcs-calc-deferred-revenue --date-start 2013-01-01 --date-end 2017-10-31 \
+        --date-old-limit 2013-01-01 --full --output-file ~/output.csv
+
+Wait for a while and check the output at `~/output.csv`.
+
 _
     args => {
         %args_db,
@@ -420,7 +444,7 @@ WHERE
   i.status='Paid' AND
   i.datepaid IS NOT NULL AND
   ii.amount <> 0 $extra_wheres
-ORDER BY ii.invoiceid
+ORDER BY i.datepaid
 _
 
     log_info "Loading all paid invoice items ...";
@@ -599,7 +623,7 @@ App::WHMCSUtils - CLI utilities related to WHMCS
 
 =head1 VERSION
 
-This document describes version 0.002 of App::WHMCSUtils (from Perl distribution App-WHMCSUtils), released on 2018-01-25.
+This document describes version 0.003 of App::WHMCSUtils (from Perl distribution App-WHMCSUtils), released on 2018-01-25.
 
 =head1 FUNCTIONS
 
@@ -615,7 +639,7 @@ then defers the revenue to separate months for items that should be deferred,
 and finally sums the amounts to calculate total monthly deferred revenues.
 
 This utility can also be instructed (via setting the C<full> option to true) to
-output the full report (each items with their categorizations and deferred
+output the full CSV report (each items with their categorizations and deferred
 revenues).
 
 Recognizes English and Indonesian description text.
@@ -637,6 +661,30 @@ ending dates and the dates are not too old.
 
 Extra rules (applied first) can be specified via the C<extra_rules> option.
 
+To use this utility, install the Perl CPAN distribution L<App::WHMCSUtils>.
+Then, create a configuration file C<~/whmcs-calc-deferred-revenue.conf>
+containing something like:
+
+ db_name=YOURDBNAME
+ db_host=YOURDBHOST
+ db_user=YOURDBUSER
+ db_pass=YOURDBPASS
+
+C<db_host> defaults to C<localhost>. C<db_user> and C<db_pass> can be omitted if you
+have C</etc/my.cnf> or C<~/.my.cnf>. This utility can search for username/password
+from those files.
+
+You can also add other configuration like C<extra_rules>, e.g.:
+
+ extra_rules=[{"type": "^$", "description": "^(?^i)sewa\\b.*ruang", "category": "rent"}]
+
+You can then run the utility for the desired, e.g.:
+
+ % whmcs-calc-deferred-revenue --date-start 2013-01-01 --date-end 2017-10-31 \
+     --date-old-limit 2013-01-01 --full --output-file ~/output.csv
+
+Wait for a while and check the output at C<~/output.csv>.
+
 This function is not exported.
 
 Arguments ('*' denotes required arguments):
